# This file is necessary for registering celery tasks

from .backends.celery import consume  # noqa
